@@ -9,7 +9,7 @@ def get_target(name=None):
         try:
             target = SSH(name=name, host=name)
         except:
-            return None
+            target = None
     else:
         target = Local()
     return target
