@@ -34,9 +34,19 @@ class Packager(Manager):
         else:
             yield from self.do_available()
 
+    def bigs(self):
+        info('\tbigs')
+        yield from self.do_bigs()
+
+    def upgradable(self):
+        info('\tupgradable')
+        yield from self.do_upgradable()
+
     def update(self):
         info('\tupdate')
         self.do_update()
+        for name, ver in self.upgradable():
+            info(f'\t\t{name}')
 
     def upgrade(self):
         info('\tupgrade')
@@ -55,14 +65,16 @@ class Packager(Manager):
         pkg = self.pkgmap.get(name, name)
         self.do_remove(pkg)
 
-    def clenup(self):
+    def cleanup(self):
         info('\tcleanup')
         self.do_cleanup()
 
     def do_init(self): todo(self)
     def do_update(self): todo(self)
+    def do_upgradable(self): todo(self)
     def do_upgrade(self): todo(self)
     def do_install(self, pkg, ver=None): todo(self)
+    def do_bigs(self): todo(self)
     def do_remove(self, pkg): todo(self)
     def do_cleanup(self): todo(self)
     def do_installed(self): todo(self)
