@@ -3,7 +3,7 @@ from os import walk
 from os.path import join, commonpath
 from sys import path as syspath
 
-from setux.logger import error, debug
+from setux.logger import debug
 
 
 def filter_py(name):
