@@ -1,7 +1,9 @@
-from setux.logger import debug, error, exception, info
 from setux.core.package import Packager
 
 
+# pylint: disable=no-member
+
+
 class Npm(Packager):
     system = False
 
