@@ -5,7 +5,7 @@ from setux.core.manage import SpecChecker
 class Group(SpecChecker):
     def get(self):
         group = self.key if self.key else self.spec['gid']
-        ret, out, err = self.run(f'grep {group} /etc/group')
+        ret, out, err = self.run(f'grep ^{group}: /etc/group')
         for line in out:
             name, x, gid, users = line.split(':')
             if self.key:
