@@ -1,4 +1,4 @@
-from setux.logger import error
+from setux.logger import error, debug
 from setux.util import rm_ansi_codes
 from setux.core.package import Packager
 
@@ -17,6 +17,29 @@ class Apt(Packager):
             name = decolor(name.split('/')[0])
             yield name, ver
 
+    def do_bigs(self):
+        ret, out, err = self.target.script('''
+            #!/bin/bash
+            dpkg-query -Wf '${Installed-Size;9} ${Package}\n' | sort -n | tail -n 22
+        ''', report='quiet')
+        for line in out:
+            yield line
+
+    def do_upgradable(self):
+        ret, out, err = self.run('''
+            apt list --upgradable
+        ''', report='quiet')
+        decolor = rm_ansi_codes
+        for line in out:
+            if not line.strip(): continue
+            try:
+                line = decolor(line)
+                name_ver = line.split()[0]
+                name, ver = name_ver.split('/')
+                yield name, ver
+            except:
+                debug(line)
+
     def do_available(self):
         ret, out, err = self.run('apt list', report='quiet')
         decolor = rm_ansi_codes
