@@ -1,10 +1,12 @@
-from setux.logger import error
+from setux.logger import error, debug
 from setux.core.package import Packager
+from setux.util import rm_ansi_codes
 
 
 class Dnf(Packager):
 
     def parse(self, line):
+        line = rm_ansi_codes(line)
         name, ver, _ = line.split()
         name = name.split('.')[0]
         return name, ver
@@ -19,6 +21,24 @@ class Dnf(Packager):
                 yield self.parse(line)
             except: pass
 
+    def do_bigs(self):
+        ret, out, err = self.target.script('''
+            #!/bin/bash
+            dnf repoquery --installed --queryformat '%9{size} %{name}' | sort -n | tail -n 22
+        ''', report='quiet')
+        for line in out:
+            yield line
+
+    def do_upgradable(self):
+        ret, out, err = self.run('''
+            dnf list --upgrades
+        ''', report='quiet')
+        for line in out:
+            try:
+                yield self.parse(line)
+            except Exception as x:
+                debug(line)
+
     def do_available(self):
         ret, out, err = self.run('dnf list --available', report='quiet')
         for line in out:
@@ -33,7 +53,7 @@ class Dnf(Packager):
         self.run('dnf clean all')
 
     def do_update(self):
-        self.run('dnf update -y')
+        self.run('dnf check-update -y')
 
     def do_upgrade(self):
         self.run('dnf upgrade -y')
