@@ -38,7 +38,7 @@ class SSH(Target):
         return ret, out, err
 
     def __call__(self, command, **kw):
-        ret, out, err = self.run(command, **kw)
+        ret, out, err = self.run(f'"{command}"', **kw)
         print('\n'.join(out))
         return ret
 
@@ -68,22 +68,24 @@ class SSH(Target):
         info(f'\tsync {src} -> {dst}')
         self.rsync(f'{src} {self.user}@{self.host}:{dst}')
 
-    def read(self, path, mode='rt', critical=True):
-        info(f'\tread {path}')
+    def read(self, path, mode='rt', critical=True, report='normal'):
+        if report=='normal':
+            info(f'\tread {path}')
         with NamedTemporaryFile(mode=mode) as tmp:
             self.fetch(path, tmp.name, quiet=True)
             content = tmp.read()
         return content
 
-    def write(self, path, content, mode='wt'):
-        info(f'\twrite {path}')
+    def write(self, path, content, mode='wt', report='normal'):
+        if report=='normal':
+            info(f'\twrite {path}')
         dest = path[:path.rfind('/')]
-        self.run(f'mkdir -p {dest}')
+        self.run(f'mkdir -p {dest}', report=report)
         with NamedTemporaryFile(mode=mode) as tmp:
             tmp.write(content)
             tmp.flush()
             self.send(tmp.name, path, quiet=True)
-        return self.read(path, mode=mode.replace('w','r')) == content
+        return self.read(path, mode=mode.replace('w','r'), report='quiet') == content
 
     def export(self, path):
         info(f'\texport -> {path}')
