@@ -6,7 +6,7 @@ from inspect import currentframe, getouterframes
 
 # remove ansi codes
 rm_ansi_codes = partial(rec(
-    r'\x1B\[([0-9]{1,3}(;[0-9]{1,2})?)?[mGK]'
+    r'\x1B\[([0-9]{1,3}(;[0-9]{1,2})?)?[mGK](\x0F)?'
 ).sub, '')
 
 
@@ -25,6 +25,7 @@ def memo(fct):
     return wrapper
 
 
+# Convert file permissions from str to oct
 def oct_mod(str_mod):
     assert len(str_mod)==9, f'bad mode : {str_mod} ({len(str_mod)})'
     def digit(str_bits):
@@ -40,6 +41,8 @@ def oct_mod(str_mod):
     ]
     return  ''.join(digits)
 
+
+# Default implementation for abstract methods
 def todo(self):
     cls = self.__class__.__name__
     mth = getouterframes(currentframe())[1][3]
